@@ -4,6 +4,8 @@
 
 import os
 import re
+from pathlib import Path
+from subprocess import run
 from sys import platform
 
 import markdown
@@ -114,7 +116,13 @@ list-style-type: none !important;
 {tasklist}
 """
         printed = """@media print {
-.button { display: none }
+.button { display: none; }
+body { 
+    background-color: white !important;
+    color: black !important;
+    }
+
+kbd { color: black !important; }
 }
 </style>
 <body>
@@ -168,10 +176,18 @@ list-style-type: none !important;
         del fcs
         with open(f"{filename}.html", "w") as whtm:
             whtm.write(cssstyle)
+        pro = None
         if platform.startswith("win"):
-            os.startfile(f"{filename}.html")
+            pro = [
+                "powershell.exe",
+                "start",
+                "msedge",
+                f"'\"{Path(f'{filename}.html').absolute()}\"'",
+            ]
+            run(pro)
         else:
-            os.system(f'open "{filename}.html"')
+            pro = ["open", "-a", "Safari", f"{Path(f'{filename}.html').absolute()}"]
+            run(pro)
         del (
             text,
             filename,
@@ -188,6 +204,7 @@ list-style-type: none !important;
             cssstyle,
             printed,
             nxt,
+            pro,
         )
     except Exception as e:
         raise e
